@@ -1,10 +1,4 @@
 
-.First.lib<- function(lib, pkg)
-{
-	library.dynam("GWASExactHW", pkg, lib)
-
-}
-
 
 HWExact <- function(GenotypeCounts) 
 {
@@ -45,4 +39,4 @@ HWExact <- function(GenotypeCounts)
 	
 	
 
-    
\ No newline at end of file
+    
